import _defineProperty from "@babel/runtime/helpers/defineProperty";
import _extends from "@babel/runtime/helpers/extends";
import _toConsumableArray from "@babel/runtime/helpers/toConsumableArray";
import _classCallCheck from "@babel/runtime/helpers/classCallCheck";
import _createClass from "@babel/runtime/helpers/createClass";
import _inherits from "@babel/runtime/helpers/inherits";
import _createSuper from "@babel/runtime/helpers/createSuper";
// TODO: 4.0 - codemod should help to change `filterOption` to support node props.
import * as React from 'react';
import omit from 'omit.js';
import classNames from 'classnames';
import { isEmpty, isArray, intersection, split, find } from 'lodash';
import RcSelect, { Option, OptGroup } from 'rc-select';
import { ConfigConsumer } from '../config-provider';
import getIcons from './utils/iconUtil';
import AngleDown from '../icon/AngleDown';
import SizeContext from '../config-provider/SizeContext'; // We still use class here since `forwardRef` not support generic in typescript

var Select = /*#__PURE__*/function (_React$Component) {
  _inherits(Select, _React$Component);

  var _super = _createSuper(Select);

  function Select() {
    var _this;

    _classCallCheck(this, Select);

    _this = _super.apply(this, arguments);
    _this.selectRef = /*#__PURE__*/React.createRef();
    _this.state = {
      multiValues: _this.props.defaultValue || [],
      searchValue: '',
      options: []
    };

    _this.focus = function () {
      if (_this.selectRef.current) {
        _this.selectRef.current.focus();
      }
    };

    _this.blur = function () {
      if (_this.selectRef.current) {
        _this.selectRef.current.blur();
      }
    };

    _this.getMode = function () {
      var mode = _this.props.mode;

      if (mode === 'combobox') {
        return undefined;
      }

      if (mode === Select.SECRET_COMBOBOX_MODE_DO_NOT_USE) {
        return 'combobox';
      }

      return mode;
    };

    _this.handleChange = function (values, option) {
      var onChange = _this.props.onChange;

      _this.setState({
        multiValues: values,
        options: option
      });

      if (onChange) {
        onChange(values, isArray(values) ? values.map(function (item) {
          return find(option, {
            value: item
          }) || {
            value: item
          };
        }) : option);
      }
    };

    _this.onSearch = function (searchValue) {
      _this.setState({
        searchValue: searchValue
      });

      var multiValues = _this.state.multiValues;
      var _this$props = _this.props,
          _this$props$tokenSepa = _this$props.tokenSeparators,
          tokenSeparators = _this$props$tokenSepa === void 0 ? [] : _this$props$tokenSepa,
          onSearch = _this$props.onSearch;

      var mode = _this.getMode();

      if (onSearch) onSearch(searchValue);

      if (!isEmpty(tokenSeparators) && mode === 'multiple') {
        var separators = intersection(split(searchValue, ''), tokenSeparators);
        var values = split(searchValue, separators[0]).filter(function (item) {
          return item;
        });

        if (!isEmpty(separators)) {
          _this.setValues(_toConsumableArray(new Set([].concat(_toConsumableArray(multiValues), _toConsumableArray(values)))));
        }
      }
    };

    _this.onInputKeyDown = function (e) {
      e.persist();
      var _this$state = _this.state,
          multiValues = _this$state.multiValues,
          searchValue = _this$state.searchValue;
      var onInputKeyDown = _this.props.onInputKeyDown;
      if (onInputKeyDown) onInputKeyDown(e);

      if (e.keyCode === 13 && searchValue) {
        _this.setValues([].concat(_toConsumableArray(multiValues), [searchValue]));
      }
    };

    _this.setValues = function (values) {
      var onChange = _this.props.onChange;
      var options = _this.state.options;

      _this.setState({
        multiValues: values,
        searchValue: ''
      }, function () {
        if (onChange) {
          onChange(values, values.map(function (item) {
            return find(options, {
              value: item
            }) || {
              value: item
            };
          }));
        }

        _this.blur();

        _this.focus();
      });
    };

    _this.renderSelect = function (_ref) {
      var getContextPopupContainer = _ref.getPopupContainer,
          getPrefixCls = _ref.getPrefixCls,
          renderEmpty = _ref.renderEmpty,
          direction = _ref.direction;
      var _this$props2 = _this.props,
          customizePrefixCls = _this$props2.prefixCls,
          notFoundContent = _this$props2.notFoundContent,
          className = _this$props2.className,
          customizeSize = _this$props2.size,
          _this$props2$listHeig = _this$props2.listHeight,
          listHeight = _this$props2$listHeig === void 0 ? 256 : _this$props2$listHeig,
          _this$props2$listItem = _this$props2.listItemHeight,
          listItemHeight = _this$props2$listItem === void 0 ? 32 : _this$props2$listItem,
          getPopupContainer = _this$props2.getPopupContainer,
          dropdownClassName = _this$props2.dropdownClassName,
          bordered = _this$props2.bordered,
          addNewValue = _this$props2.addNewValue;
      var prefixCls = getPrefixCls('select', customizePrefixCls);

      var mode = _this.getMode();

      var isMultiple = mode === 'multiple' || mode === 'tags'; // ===================== Empty =====================

      var mergedNotFound;

      if (notFoundContent !== undefined) {
        mergedNotFound = notFoundContent;
      } else if (mode === 'combobox') {
        mergedNotFound = null;
      } else {
        mergedNotFound = renderEmpty('Select');
      } // ===================== Icons =====================


      var _getIcons = getIcons(_extends(_extends({}, _this.props), {
        multiple: isMultiple
      })),
          itemIcon = _getIcons.itemIcon,
          removeIcon = _getIcons.removeIcon,
          clearIcon = _getIcons.clearIcon; // ===================== addNewValue =====================


      var selectProps = omit(_this.props, ['prefixCls', 'suffixIcon', 'itemIcon', 'removeIcon', 'clearIcon', 'size', 'bordered']);

      if (mode === 'multiple' && addNewValue) {
        if (selectProps.tokenSeparators) delete selectProps.tokenSeparators;
        selectProps = _extends(_extends({}, selectProps), {
          value: _this.state.multiValues,
          onSearch: _this.onSearch,
          onChange: _this.handleChange,
          onInputKeyDown: _this.onInputKeyDown
        });
      }

      var rcSelectRtlDropDownClassName = classNames(dropdownClassName, _defineProperty({}, "".concat(prefixCls, "-dropdown-").concat(direction), direction === 'rtl'));
      return /*#__PURE__*/React.createElement(SizeContext.Consumer, null, function (size) {
        var _classNames2;

        var mergedSize = customizeSize || size;
        var mergedClassName = classNames(className, (_classNames2 = {}, _defineProperty(_classNames2, "".concat(prefixCls, "-lg"), mergedSize === 'large'), _defineProperty(_classNames2, "".concat(prefixCls, "-sm"), mergedSize === 'small'), _defineProperty(_classNames2, "".concat(prefixCls, "-rtl"), direction === 'rtl'), _defineProperty(_classNames2, "".concat(prefixCls, "-borderless"), !bordered), _classNames2));
        return /*#__PURE__*/React.createElement(RcSelect, _extends({
          ref: _this.selectRef
        }, selectProps, {
          listHeight: listHeight,
          listItemHeight: listItemHeight,
          mode: mode,
          prefixCls: prefixCls,
          direction: direction,
          inputIcon: AngleDown,
          menuItemSelectedIcon: itemIcon,
          removeIcon: removeIcon,
          clearIcon: clearIcon,
          notFoundContent: mergedNotFound,
          className: mergedClassName,
          getPopupContainer: getPopupContainer || getContextPopupContainer,
          dropdownClassName: rcSelectRtlDropDownClassName
        }));
      });
    };

    return _this;
  }

  _createClass(Select, [{
    key: "render",
    value: function render() {
      return /*#__PURE__*/React.createElement(ConfigConsumer, null, this.renderSelect);
    }
  }]);

  return Select;
}(React.Component);

Select.Option = Option;
Select.OptGroup = OptGroup;
Select.SECRET_COMBOBOX_MODE_DO_NOT_USE = 'SECRET_COMBOBOX_MODE_DO_NOT_USE';
Select.defaultProps = {
  transitionName: 'slide-up',
  choiceTransitionName: 'zoom',
  bordered: true,
  addNewValue: false
};
export default Select;